@@ -9,27 +9,29 @@ def build_config() -> dict[str, str]:
 
     All dictionary keys and values are strings, for example ``False`` is
     returned as ``"False"``.
+
+        .. versionadded:: 1.1.0
     """
     return dict(
         # Python settings
-        python_version="3.11",
-        python_install_dir=r"/usr/local/lib/python3.11/site-packages/",
+        python_version="3.12",
+        python_install_dir=r"/usr/local/lib/python3.12/site-packages/",
         python_path=r"/usr/bin/python",
 
         # Package versions
-        contourpy_version="1.1.0",
-        meson_version="1.1.1",
-        mesonpy_version="0.13.1",
-        pybind11_version="2.10.4",
+        contourpy_version="1.2.1",
+        meson_version="1.4.0",
+        mesonpy_version="0.15.0",
+        pybind11_version="2.12.0",
 
         # Misc meson settings
         meson_backend="ninja",
-        build_dir=r"/build/python-contourpy/src/contourpy-1.1.0/.mesonpy-55dd_ei8/build/lib/contourpy/util",
-        source_dir=r"/build/python-contourpy/src/contourpy-1.1.0/lib/contourpy/util",
+        build_dir=r"/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-m4a3y4gt/lib/contourpy/util",
+        source_dir=r"/build/python-contourpy/src/contourpy-1.2.1/lib/contourpy/util",
         cross_build="False",
 
         # Build options
-        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.1.0/.mesonpy-55dd_ei8/build/meson-python-native-file.ini",
+        build_options=r"-Dbuildtype=release -Db_ndebug=if-release -Db_vscrt=md -Dvsenv=True --native-file=/build/python-contourpy/src/contourpy-1.2.1/.mesonpy-m4a3y4gt/meson-python-native-file.ini",
         buildtype="release",
         cpp_std="c++17",
         debug="False",
@@ -40,7 +42,7 @@ def build_config() -> dict[str, str]:
 
         # C++ compiler
         compiler_name="gcc",
-        compiler_version="13.1.1",
+        compiler_version="13.2.1",
         linker_id="ld.bfd",
         compile_command="c++",
 
